@@ -1,6 +1,8 @@
+from pdb import runcall
 import sys
 import os
-from language import language_dict
+from indicpy.language import language_dict
+from indicpy.exceptions import *
 from typing import List
 import tokenize
 import argparse
@@ -81,14 +83,29 @@ def get_runnable_script(file_path: str, write_path: str) -> None:
 	with open(write_path, 'w') as f:
 		f.write(code)
 
+def validate_file(file_path: str) -> bool:
+	""" Check if the given file is a indic python file. """
+	extension = file_path.split('.')[-1]
+	if not extension.startswith('py') and not extension.startswith('epy'):
+		raise NotIndicPythonFileException(file_path)
+	language = extension[2:] if extension.startswith('py') else extension[3:]
+	if language not in language_dict.keys():
+		raise UnknownLanguageException(language)
+	return True
+
 def get_executable_code(file_path: str) -> str:
 	""" Convert the indic python code. """
+	# Validate the file path.
+	validate_file(file_path)
+
 	# The language of the code to be converted and run.
-	language = language_dict[file_path.split('.')[-1][2:]]
+	extension = file_path.split('.')[-1]
+	is_english = extension[0] == 'e'
+	language = language_dict[extension[2:]] if extension.startswith('py') else language_dict[extension[3:]]
 
 	# Load the language map.
 	directory, _ = os.path.split(__file__)
-	DATA_PATH = os.path.join(directory, "keywords", language + ".yml")
+	DATA_PATH = os.path.join(directory, "keywords", language + ("_english.yml" if is_english else ".yml"))
 	with open(DATA_PATH, 'rb') as f:
 		yml_lines = [line.decode('utf-8').strip() for line in f]
 		keywords = {}
@@ -116,5 +133,11 @@ def run_cli():
 
 	# The file path of the code to be converted and run.
 	file_path = argument_parser.parse_args().Path
-	code = get_executable_code(file_path)
-	exec(code)
\ No newline at end of file
+	try:
+		validate_file(file_path)
+		code = get_executable_code(file_path)
+		exec(code)
+	except NotIndicPythonFileException as e:
+		print(f"{e.file_path} is not a indic python file.")
+	except UnknownLanguageException as e:
+		print(f"{e.language} is not a supported language.")
\ No newline at end of file
