@@ -1,3 +1,3 @@
-from src.indicpy import get_executable_code
+from indicpy import get_executable_code
 
 print(get_executable_code("indicpy/examples/kannada.pykn"))
\ No newline at end of file
